@@ -1,4 +1,4 @@
-# Copyright 2016 - 2019  Ternaris.
+# Copyright 2016 - 2021  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
 import asyncio
@@ -11,13 +11,12 @@ from pathlib import Path
 from aiohttp import web
 from pkg_resources import resource_filename
 
-import marv_webapi
 from marv.collection import cached_property
 from marv_api.utils import find_obj
-from marv_webapi.tooling import safejoin
+from marv_webapi.api import api
+from marv_webapi.tooling import Webapi, auth_middleware, safejoin
 
 DOCS = Path(resource_filename('marv.app', 'docs'))
-LOADED = False
 log = getLogger(__name__)
 
 
@@ -42,16 +41,13 @@ class App():
     NOCACHE = {'Cache-Control': 'no-cache'}
 
     def __init__(self, site, app_root='', middlewares=None):
-        self.aioapp = web.Application(middlewares=middlewares or [])
-        self.aioapp['api_endpoints'] = {}
+        self.aioapp = web.Application(middlewares=[*(middlewares or []), auth_middleware])
         self.aioapp['app_root'] = app_root.rstrip('/')
         self.aioapp['config'] = {
             'SECRET_KEY': site.config.marv.sessionkey_file.read_text(),
         }
         self.aioapp['debug'] = False
-        self.aioapp['route_acl'] = find_obj(site.config.marv.acl)()
         self.aioapp['site'] = site
-        self.aioapp.route = self.route
 
         for func in self.STARTUP_FNS:
             self.aioapp.on_startup.append(func)
@@ -59,13 +55,10 @@ class App():
         for func in self.SHUTDOWN_FNS:
             self.aioapp.on_shutdown.append(func)
 
+        self.api = Webapi()
+        self.api.endpoints.extend(api.endpoints)
         self.initialize_routes()
 
-    def route(self, path):
-        def dec(func):
-            self.aioapp.add_routes([web.route('GET', f'{self.aioapp["app_root"]}{path}', func)])
-        return dec
-
     @cached_property
     def index_html(self):
         path = self.aioapp['site'].config.marv.staticdir / 'index.html'
@@ -87,19 +80,13 @@ class App():
         return index_html
 
     def initialize_routes(self):
-        global LOADED  # pylint: disable=global-statement
-        if not LOADED:
-            marv_webapi.load_entry_points()
-            LOADED = True
-        marv_webapi.webapi.init_app(self.aioapp, url_prefix='/marv/api',
-                                    app_root=self.aioapp['app_root'])
         aggressive_caching = bool(os.environ.get('MARV_EXPERIMENTAL_AGGRESSIVE_CACHING'))
 
         customdir = self.aioapp['site'].config.marv.frontenddir / 'custom'
         staticdir = self.aioapp['site'].config.marv.staticdir
 
         # decorator for non api endpoint routes
-        @self.route('/custom/{path:.*}')
+        @self.api.endpoint('/custom/{path:.*}', methods=['GET'], allow_anon=True)
         async def custom(request):  # pylint: disable=unused-variable
             path = request.match_info['path']
             fullpath = safejoin(customdir, path)
@@ -107,12 +94,12 @@ class App():
                 raise web.HTTPNotFound
             return web.FileResponse(fullpath, headers=self.NOCACHE)
 
-        @self.route(r'/docs{_:/?}{path:((?<=/).*)?}')
+        @self.api.endpoint(r'/docs{_:/?}{path:((?<=/).*)?}', methods=['GET'], allow_anon=True)
         async def docs(request):  # pylint: disable=unused-variable
             path = request.match_info['path'] or 'index.html'
             return web.FileResponse(safejoin(DOCS, path), headers={'Cache-Control': 'no-cache'})
 
-        @self.route('/{path:.*}')
+        @self.api.endpoint('/{path:.*}', methods=['GET'], allow_anon=True)
         async def assets(request):  # pylint: disable=unused-variable
             path = request.match_info['path'] or 'index.html'
             if path == 'index.html':
@@ -128,3 +115,9 @@ class App():
             headers = (self.CACHE if aggressive_caching and fullpath.suffix == '.svg' else
                        self.NOCACHE)
             return web.FileResponse(fullpath, headers=headers)
+
+        for ep in self.api.endpoints:
+            name = ep.name
+            path = f'{self.aioapp["app_root"]}{ep.url_rule}'
+            for method in ep.methods:
+                self.aioapp.add_routes([web.route(method, path, ep, name=name)])
