@@ -1,4 +1,4 @@
-# Copyright 2016 - 2018  Ternaris.
+# Copyright 2016 - 2021  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Marv config parsing."""
@@ -15,7 +15,6 @@ from typing import Any, Dict, Optional, Tuple
 from pkg_resources import resource_filename
 from pydantic import BaseModel, Extra, ValidationError, validator
 
-from marv_api.deprecation import deprecated
 from marv_api.utils import echo
 
 from . import sexp
@@ -31,15 +30,6 @@ class InvalidToken(Exception):
     pass
 
 
-@deprecated(
-    '21.04',
-    'use makelist and filter instead (list (...)) -> (filter null (makelist (...))).',
-    name='list',
-)
-def deprecated_list(*args):
-    return list(filter(None, args))
-
-
 def make_funcs(dataset, setdir, store):
     """Functions available for listing columns and filters."""
     return {
@@ -52,11 +42,11 @@ def make_funcs(dataset, setdir, store):
         'getitem': lambda x, y: x[y] if x is not None else None,
         'join': lambda sep, *args: sep.join([x for x in args if x]),
         'len': lambda x: len(x) if x is not None else None,
+        'leaf': lambda x: [f'#LEAF.{x}#'],
         'link': (lambda href, title, target=None:
                  {'href': href or '',
                   'title': title or '',
                   'target': '_blank' if target is None else target}),
-        'list': deprecated_list,
         'makelist': lambda *x: list(x),
         'max': lambda x: max(x) if x else None,
         'min': lambda x: min(x) if x else None,
@@ -269,13 +259,17 @@ reapvalidator = partial(validator, allow_reuse=True, always=True, pre=True)
 class MarvConfig(Model):
     sitedir: Path  # TODO: workaround
     collections: Tuple[str, ...]
-    acl: str = 'marv_webapi.acls:authenticated'
+    ce_anonymous_readonly_access: bool = False
     dburi: str = 'sqlite://db/db.sqlite'
     frontenddir: Path = 'frontend'
+    leavesdir: Path = 'leaves'
+    mail_footer: str = ''
     oauth: Dict[str, Tuple[str, ...]] = None
     reverse_proxy: Optional[ReverseProxyEnum] = None
     resourcedir: Path = 'resources'
     sessionkey_file: Path = 'sessionkey'
+    smtp_url: str = 'smtp://'
+    smtp_from: str = ''
     staticdir: Path = resource_filename('marv', 'app/static')
     storedir: Path = 'store'
     upload_checkpoint_commands: Tuple[str, ...] = None
@@ -286,8 +280,9 @@ class MarvConfig(Model):
         return self.venv / 'lib' / f'python{sysconfig.get_python_version()}' / 'site-packages'
 
     _resolve_path = reapvalidator('sitedir')(resolve_path)
-    _resolve_relto_site = reapvalidator('frontenddir', 'resourcedir', 'sessionkey_file',
-                                        'staticdir', 'storedir', 'venv')(resolve_relto_site)
+    _resolve_relto_site = reapvalidator('frontenddir', 'leavesdir', 'resourcedir',
+                                        'sessionkey_file', 'staticdir', 'storedir',
+                                        'venv')(resolve_relto_site)
     _split = reapvalidator('collections')(split)
     _splitlines_split = reapvalidator('upload_checkpoint_commands')(splitlines_split)
     _strip = reapvalidator('reverse_proxy')(strip)
