@@ -1,10 +1,11 @@
 # Copyright 2016 - 2020  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
-import mock
+from unittest import mock
+
 import pytest
 
-from marv.db import DBNotInitialized, DBVersionError, Database
+from marv.db import Database, DBNotInitialized, DBVersionError
 from marv.site import Site
 
 
