@@ -9,13 +9,7 @@ from datetime import datetime, timedelta
 from datetime import tzinfo as tzinfo_base
 from itertools import islice
 
-from marv_api import deprecation
 from marv_api.utils import NOTSET
-from marv_api.utils import popen as _popen
-
-__getattr__ = deprecation.make_getattr(__name__, {
-    'popen': deprecation.Info(__name__, '21.04', _popen, 'use marv_api.utils.popen instead.'),
-})
 
 
 def chunked(iterable, chunk_size):
